Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1552)

Unified Diff: Source/core/xml/DocumentXMLTreeViewer.h

Issue 479753003: Transform XML tree viewer to blink-in-js implementation. (Closed) Base URL: https://chromium.googlesource.com/chromium/blink.git@master
Patch Set: Created 6 years, 4 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « Source/core/core_generated.gyp ('k') | Source/core/xml/DocumentXMLTreeViewer.idl » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: Source/core/xml/DocumentXMLTreeViewer.h
diff --git a/Source/core/testing/PartialPrivateScriptTest.h b/Source/core/xml/DocumentXMLTreeViewer.h
similarity index 61%
copy from Source/core/testing/PartialPrivateScriptTest.h
copy to Source/core/xml/DocumentXMLTreeViewer.h
index 5562fa6d799b93e7faf83b4dce873a11ea53519c..843e5b74713551b6f0b65bfb55898eb540227f1d 100644
--- a/Source/core/testing/PartialPrivateScriptTest.h
+++ b/Source/core/xml/DocumentXMLTreeViewer.h
@@ -2,14 +2,14 @@
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.
-#ifndef PartialPrivateScriptTest_h
-#define PartialPrivateScriptTest_h
+#ifndef DocumentXMLTreeViewer_h
+#define DocumentXMLTreeViewer_h
namespace blink {
// FIXME: This header file is needed because auto-generated binding tries to include
-// PartialPrivateScriptTest.h. We should improve the IDL compiler and remove this file.
-class PartialPrivateScriptTest {
+// DocumentXMLTreeViewer.h. We should improve the IDL compiler and remove this file.
haraken 2014/08/26 08:56:19 I'll fix this in a follow-up CL.
+class DocumentXMLTreeViewer {
};
} // namespace blink
« no previous file with comments | « Source/core/core_generated.gyp ('k') | Source/core/xml/DocumentXMLTreeViewer.idl » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698